==> oddmuse-1.754.tar.gz: oddmuse-1.754/new-utf8.pl <==
# UTF-8 encoded FIXME translation file for use with Oddmuse
#
# Copyright (c) 2004  FIXME
#
# Permission is granted to copy, distribute and/or modify this
# document under the terms of the GNU Free Documentation License,
# Version 1.2 or any later version published by the Free Software
# Foundation; with no Invariant Sections, no Front-Cover Texts, and no
# Back-Cover Texts.  A copy of the license could be found at:
# http://www.gnu.org/licenses/fdl.txt .
#
# Installation:
# =============
#
# Create a modules subdirectory in your data directory, and put the
# file in there. It will be loaded automatically.
#
$ModulesDescription .= '<p>$Id: new-utf8.pl,v 1.10 2006/08/18 22:46:10 as Exp $</p>';
%Translate = split(/\n/,<<END_OF_TRANSLATION);
Reading not allowed: user, ip, or network is blocked.

%s calls

Could not create %s

Invalid UserName %s: not saved.

UserName must be 50 characters or less: not saved

This page contains an uploaded file:

Recursive include of %s!

Clear Cache

Main lock obtained.

Main lock released.

Comments on this page

XML::RSS is not available on this system.

diff

history

%s returned no data, or LWP::UserAgent is not available.

RSS parsing failed for %s

No items found in %s.

 . . . . 

Click to edit this page

image

download

CGI Internal error: %s

Invalid action parameter %s

Invalid URL.

Page name is missing

Page name is too long: %s

Invalid Page %s (must not end with .db)

Invalid Page %s (must not end with .lck)

Invalid Page %s

Preview:

Preview only, not yet saved

Please go on to %s.

No updates since %s

Updates since %s

Updates in the last %s days

Updates in the last %s day

for %s only

List latest change per page only

List all changes

Skip rollbacks

Include rollbacks

List only major changes

Include minor changes

%s days

List later changes

Filters

Title:

Title and Body:

Username:

Host:

Language:

Go!

(minor)

rollback

new

from %s

This page is too big to send over RSS.

History of %s

Compare

Deleted

Mark this page for deletion

No other revisions available

current

Revision %s

Contributors to %s

Missing target for rollback.

Target for rollback is too far back.

Rolling back changes

The two revisions are the same.

Editing not allowed for %s.

Rollback to %s

%s rolled back

to %s

Index of all pages

Wiki Version

Unlock Wiki

Password

Run maintenance

Unlock site

Lock site

Install CSS

Unlock %s

Lock %s

Administration

Actions:

Important pages:

To mark a page for deletion, put <strong>%s</strong> on the first line.

[Home]

redirected from %s

Click to search for references to this page

Cookie: 

Warning

Database is stored in temporary directory %s

%s seconds

The same page on other sites:

EditNearLinks

Last edited

Edited

by %s

(diff)

Edit revision %s of this page

Edit this page

e

This page is read-only

View other revisions

View current revision

View all changes

View contributors

Homepage URL:

s

Save

p

Preview

Search:

f

Replace:

Validate HTML

Validate CSS

Last edit

Difference between revision %1 and %2

revision %s

current revision

Last major edit (%s)

later minor edits

No diff available.

Old revision:

Changed:

Deleted:

Added:

to

Revision %s not available

showing current revision instead

Showing revision %s

Cannot save a nameless page.

Cannot save a page without revision.

Cannot open %s

Cannot write %s

Cannot create %s

Could not get %s lock

The lock was created %s.

This operation may take several seconds...

Forced unlock of %s lock.

No unlock required.

%s hours ago

1 hour ago

%s minutes ago

1 minute ago

%s seconds ago

1 second ago

just now

Edit Denied

Editing not allowed: user, ip, or network is blocked.

Contact the wiki administrator for more information.

The rule %s matched for you.

See %s for more information.

Editing not allowed: %s is read-only.

Only administrators can upload files.

Editing revision %s of

Editing %s

Editing old revision %s.

Saving this page will replace the latest revision with this text.

Summary:

This change is a minor edit.

Replace this file with text

Replace this text with a file

File to upload: 

Files of type %s are not allowed.

Your password is saved in a cookie, if you have cookies enabled. Cookies may get lost if you connect from another machine, from another account, or using another software.

You are currently an administrator on this site.

You are currently an editor on this site.

You are a normal user on this site.

Your password does not match any of the  administrator or editor passwords.

Password:

This site does not use admin or editor passwords.

This operation is restricted to site editors only...

This operation is restricted to administrators only...

SampleUndefinedPage

Sample_Undefined_Page

Rule "%1" matched "%2" on this page.

Without normal pages

Include normal pages

Without permanent anchors

Include permanent anchors

Without near pages

Include near pages

(for %s)

Filter:

%s pages found.

Replaced: %s

Search for: %s

View changes for these pages

Search sites on the %s as well

and

or

Fetching results from %s:

Near pages:

last updated

by

Transfer Error: %s

Browser reports no file info.

Browser reports no file type.

The page contains banned text.

No changes to be saved.

This page was changed by somebody else %s.

The changes conflict.  Please check the page again.

Please check whether you overwrote those changes.

Anonymous

Cannot delete the index file %s.

Please check the directory permissions.

Your changes were not saved.

Could not get a lock to merge!

you

ancestor

other

Run Maintenance

Maintenance not done.

(Maintenance can only be done once every 12 hours.)

Remove the "maintain" file or wait.

Expiring keep files and deleting pages marked for deletion

not deleted: 

deleted

Moving part of the %s log file.

Could not open %s log file

Error was

Note: This error is normal if no changes have been made.

Moving %s log entries.

Getting page index file for %s.

Set or Remove global edit lock

Edit lock created.

Edit lock removed.

Set or Remove page edit lock

Lock for %s created.

Lock for %s removed.

Displaying Wiki Version

Show dependencies

Inter links:

Near links:

Show parsed link data

Too many connections by %s

Please do not fetch more than %1 pages in %2 seconds.

Check whether the web server can create the directory %s and whether it can create files in it.

anchor first defined here: %s

Click to search for references to this permanent anchor

the page %s also exists

Copy one of the following stylesheets to %s:

Deleting %s

Deleted %s

Renaming %1 to %2.

The page %s does not exist

The page %s already exists

Cannot rename %1 to %2

Renamed to %s

Renamed from %s

Renamed %1 to %2.

Immediately delete %s

Rename %s to:

Learn more...

Complete Content

The main page is %s.

Cannot highlight the language %s.

Recent Visitors

some action

was here

and read

Illegal year value: Use 0001-9999

The match parameter is missing.

Page Collection for %s

Previous

Next

Calendar %s

Su

Mo

Tu

We

Th

Fr

Sa

January

February

March

April

May

June

July

August

September

October

November

December

Clustermap

Pages without a Cluster

Comments on 

Comment on 

Compilation for %s

Compilation tag is missing a regular expression.

Despamming pages

Cannot find revision %s.

Revert to revision %1: %2

Marked as %s.

Cannot find unspammed revision.

Add Comment

ordinary changes

Footnotes:

Could not find %1.html template in %2

Only Editors are allowed to see this hidden page.

Only Admins are allowed to see this hidden page.

Index

Languages:

Show!

Define

Full Link List

Template without parameters

The template %s is either empty or does not exist.

 -- defined on %s

Local names defined on %1: %2

Register for %s

Please choose a username of the form "FirstLast" using your real name.

The passwords do not match.

The password must be at least %s characters.

That email address is invalid.

The username %s has already been registered.

Your registration for %s has been submitted.

Please allow time for the webmaster to approve your request.

An email has been sent to "%s" with further instructions.

There was an error saving your registration.

An account was created for %s.

Login to %s

Username and/or password are incorrect.

Logged in as %s.

Logout of %s

Logout of %s?

Logged out of %s

You are now logged out.

Register a new account

Login

Logout

Who am I?

Forgot your password?

Change your password

Approve pending registrations

Confirm Registration for %s

%s, your registration has been approved. You can now use your password to login and edit this wiki.

Confirmation failed.  Please email %s for help.

Who Am I?

You are logged in as %s.

You are not logged in.

Reset Password

The password for %s was reset.  It has been emailed to the address on file.

There was an error resetting the password for %s.

The username "%s" does not exist.

Reset Password for %s

Reset Password?

Change Password for %s

Change Password?

Your current password is incorrect.

Your password has been changed.

Approve Pending Registrations for %s

%s has been approved.

There was an error approving %s.

<ul>

<li>%1 - %2</li>

</ul>

There are no pending registrations.

%s is not a legal name for a namespace

Clearing Cache

Done.

Generating Link Database

The 404 handler extension requires the link data extension (links.pl).

LocalMap

No page id for action localmap

Requested page %s does not exist

Local Map for %s

view

Self-ban by %s

You have banned your own IP.

Orphan List

Trail: 

None

Type

Permalink to "%s"

There was an error generating the pdf for %s.  Please report this to webmaster, but do not try to download again as it will not work.

Someone else is generating a pdf for %s.  Please wait a minute and then try again.

Download this page as PDF

Portrait

Publish %s

No target wiki was specified in the config file.

The target wiki was misconfigured.

You did not answer correctly.

To save this page you must answer this question:

All Referrers

Referrers

Tag

Rebuild index for searching

Tag Cloud

Search::FreeText is not available on this system.

Rebuilding index not done.

(Rebuilding the index can only be done once every 12 hours.)

 ... 

Search term missing.

Result pages: 

(%s results)

Tags:

Tags: %s.

No tags

Slideshow:%s

Static Copy

Back to %s

Copy to %1 succeeded: %2.

Copy to %1 failed: %2.

Alternatively, use one of the following templates:

Thread: %s

ID parameter is missing.

Thread %s does not exist.

Page %s does not contain a thread.

Add

URL parameter is missing.

Add to %s thread

Below:

URL:

Name:

Failed to remove %s

Contents

This page is a translation of %s. 

The translation is up to date.

The translation is outdated.

The page does not exist.

http://search.barnesandnoble.com/booksearch/isbninquiry.asp?ISBN=%s

http://www.amazon.com/exec/obidos/ISBN=%s

alternate

http://www.pricescan.com/books/BookDetail.asp?isbn=%s

search

Wanted Pages

%s pages

%s, referenced from:

Upload of %s file

Blog

Matching pages:

New

Edit %s.

Title: 

Tags: 

END_OF_TRANSLATION

==> oddmuse-1.806.tar.gz: oddmuse-1.806/new-utf8.pl <==
# UTF-8 encoded FIXME translation file for use with Oddmuse
#
# Copyright (c) 2004  FIXME
#
# Permission is granted to copy, distribute and/or modify this
# document under the terms of the GNU Free Documentation License,
# Version 1.2 or any later version published by the Free Software
# Foundation; with no Invariant Sections, no Front-Cover Texts, and no
# Back-Cover Texts.  A copy of the license could be found at:
# http://www.gnu.org/licenses/fdl.txt .
#
# Installation:
# =============
#
# Create a modules subdirectory in your data directory, and put the
# file in there. It will be loaded automatically.
#
$ModulesDescription .= '<p>$Id: new-utf8.pl,v 1.11 2007/08/19 11:42:08 as Exp $</p>';
%Translate = split(/\n/,<<END_OF_TRANSLATION);
Reading not allowed: user, ip, or network is blocked.

Login

Error

%s calls

Could not create %s

Invalid UserName %s: not saved.

UserName must be 50 characters or less: not saved

This page contains an uploaded file:

Recursive include of %s!

Clear Cache

Main lock obtained.

Main lock released.

Journal

More...

Comments on this page

XML::RSS is not available on this system.

diff

history

%s returned no data, or LWP::UserAgent is not available.

RSS parsing failed for %s

No items found in %s.

 . . . . 

Click to edit this page

CGI Internal error: %s

Invalid action parameter %s

Invalid URL.

Page name is missing

Page name is too long: %s

Invalid Page %s (must not end with .db)

Invalid Page %s (must not end with .lck)

Invalid Page %s

Preview:

Preview only, not yet saved

Please go on to %s.

All changes for %s

No updates since %s

Updates since %s

Updates in the last %s days

Updates in the last %s day

for %s only

List latest change per page only

List all changes

Skip rollbacks

Include rollbacks

List only major changes

Include minor changes

%s days

List later changes

RSS

RSS with pages

RSS with pages and diff

Filters

Title:

Title and Body:

Username:

Host:

Follow up to:

Language:

Go!

(minor)

rollback

new

from %s

: 

This page is too big to send over RSS.

History of %s

Compare

Deleted

Mark this page for deletion

No other revisions available

current

Revision %s

Contributors to %s

Missing target for rollback.

Target for rollback is too far back.

A username is required for ordinary users.

Rolling back changes

The two revisions are the same.

Editing not allowed for %s.

Rollback to %s

%s rolled back

to %s

Index of all pages

Wiki Version

Unlock Wiki

Password

Run maintenance

Unlock site

Lock site

Install CSS

Unlock %s

Lock %s

Administration

Actions:

Important pages:

To mark a page for deletion, put <strong>%s</strong> on the first line.

[Home]

redirected from %s

Click to search for references to this page

Cookie: 

Warning

Database is stored in temporary directory %s

%s seconds

The same page on other sites:

EditNearLinks

Last edited

Edited

by %s

(diff)

Edit revision %s of this page

Edit this page

e

This page is read-only

View other revisions

View current revision

View all changes

View contributors

Homepage URL:

s

Save

p

Preview

Search:

f

Replace:

Delete

Validate HTML

Validate CSS

Last edit

Difference between revision %1 and %2

revision %s

current revision

Last major edit (%s)

later minor edits

No diff available.

Old revision:

Changed:

Deleted:

Added:

to

Revision %s not available

showing current revision instead

Showing revision %s

Cannot save a nameless page.

Cannot save a page without revision.

Cannot open %s

Cannot write %s

Cannot create %s

Could not get %s lock

The lock was created %s.

This operation may take several seconds...

Forced unlock of %s lock.

No unlock required.

%s hours ago

1 hour ago

%s minutes ago

1 minute ago

%s seconds ago

1 second ago

just now

Edit Denied

Editing not allowed: user, ip, or network is blocked.

Contact the wiki administrator for more information.

The rule %s matched for you.

See %s for more information.

Editing not allowed: %s is read-only.

Only administrators can upload files.

Editing revision %s of

Editing %s

Editing old revision %s.

Saving this page will replace the latest revision with this text.

Summary:

This change is a minor edit.

Cancel

Replace this file with text

Replace this text with a file

File to upload: 

Files of type %s are not allowed.

Your password is saved in a cookie, if you have cookies enabled. Cookies may get lost if you connect from another machine, from another account, or using another software.

You are currently an administrator on this site.

You are currently an editor on this site.

You are a normal user on this site.

Your password does not match any of the  administrator or editor passwords.

Password:

This site does not use admin or editor passwords.

This operation is restricted to site editors only...

This operation is restricted to administrators only...

SampleUndefinedPage

Sample_Undefined_Page

Rule "%1" matched "%2" on this page.

Reason: %s.

Reason unknown.

Without normal pages

Include normal pages

Without permanent anchors

Include permanent anchors

Without near pages

Include near pages

(for %s)

Filter:

%s pages found.

Replaced: %s

Search for: %s

View changes for these pages

Search sites on the %s as well

and

or

Fetching results from %s:

Near pages:

last updated

by

Transfer Error: %s

Browser reports no file info.

Browser reports no file type.

The page contains banned text.

No changes to be saved.

This page was changed by somebody else %s.

The changes conflict.  Please check the page again.

Please check whether you overwrote those changes.

Anonymous

Cannot delete the index file %s.

Please check the directory permissions.

Your changes were not saved.

Could not get a lock to merge!

you

ancestor

other

Run Maintenance

Maintenance not done.

(Maintenance can only be done once every 12 hours.)

Remove the "maintain" file or wait.

Expiring keep files and deleting pages marked for deletion

not deleted: 

deleted

Moving part of the %s log file.

Could not open %s log file

Error was

Note: This error is normal if no changes have been made.

Moving %s log entries.

Getting page index file for %s.

Set or Remove global edit lock

Edit lock created.

Edit lock removed.

Set or Remove page edit lock

Lock for %s created.

Lock for %s removed.

Displaying Wiki Version

Show dependencies

Inter links:

Near links:

Show parsed link data

Too many connections by %s

Please do not fetch more than %1 pages in %2 seconds.

Check whether the web server can create the directory %s and whether it can create files in it.

anchor first defined here: %s

Click to search for references to this permanent anchor

the page %s also exists

Copy one of the following stylesheets to %s:

Deleting %s

Deleted %s

Renaming %1 to %2.

The page %s does not exist

The page %s already exists

Cannot rename %1 to %2

Renamed to %s

Renamed from %s

Renamed %1 to %2.

Immediately delete %s

Rename %s to:

Learn more...

Complete Content

The main page is %s.

Archive:

Rebuild BackLink database

Internal Page: 

Pages that link to this page

Cannot highlight the language %s.

Recent Visitors

some action

was here

and read

Illegal year value: Use 0001-9999

The match parameter is missing.

Page Collection for %s

Previous

Next

Calendar %s

Su

Mo

Tu

We

Th

Fr

Sa

January

February

March

April

May

June

July

August

September

October

November

December

set %s

unset %s

Clustermap

Pages without a Cluster

Comments on 

Comment on 

Compilation for %s

Compilation tag is missing a regular expression.

List spammed pages

Despamming pages

Spammed pages

Cannot find revision %s.

Revert to revision %1: %2

Marked as %s.

Cannot find unspammed revision.

Recover Draft

No text to save

Draft saved

Draft recovered

No draft available to recover

Save Draft

Draft Cleanup

%1 was last modified %2 and was kept

%1 was last modified %2 and was deleted

Unable to delete draft %s

Add Comment

ordinary changes

Matching page names:

Footnotes:

Could not find %1.html template in %2

Only Editors are allowed to see this hidden page.

Only Admins are allowed to see this hidden page.

Index

Languages:

Show!

Define

Full Link List

Template without parameters

The template %s is either empty or does not exist.

 -- defined on %s

Local names defined on %1: %2

Register for %s

Please choose a username of the form "FirstLast" using your real name.

The passwords do not match.

The password must be at least %s characters.

That email address is invalid.

The username %s has already been registered.

Your registration for %s has been submitted.

Please allow time for the webmaster to approve your request.

An email has been sent to "%s" with further instructions.

There was an error saving your registration.

An account was created for %s.

Login to %s

Username and/or password are incorrect.

Logged in as %s.

Logout of %s

Logout of %s?

Logged out of %s

You are now logged out.

Register a new account

Logout

Who am I?

Forgot your password?

Change your password

Approve pending registrations

Confirm Registration for %s

%s, your registration has been approved. You can now use your password to login and edit this wiki.

Confirmation failed.  Please email %s for help.

Who Am I?

You are logged in as %s.

You are not logged in.

Reset Password

The password for %s was reset.  It has been emailed to the address on file.

There was an error resetting the password for %s.

The username "%s" does not exist.

Reset Password for %s

Reset Password?

Change Password for %s

Change Password?

Your current password is incorrect.

Your password has been changed.

Approve Pending Registrations for %s

%s has been approved.

There was an error approving %s.

<ul>

<li>%1 - %2</li>

</ul>

There are no pending registrations.

%s is not a legal name for a namespace

 (create locally)

image

download

Clearing Cache

Done.

Generating Link Database

The 404 handler extension requires the link data extension (links.pl).

LocalMap

No page id for action localmap

Requested page %s does not exist

Local Map for %s

view

Self-ban by %s

You have banned your own IP.

Orphan List

Trail: 

None

Type

Permalink to "%s"

There was an error generating the pdf for %s.  Please report this to webmaster, but do not try to download again as it will not work.

Someone else is generating a pdf for %s.  Please wait a minute and then try again.

Download this page as PDF

Portrait

Publish %s

No target wiki was specified in the config file.

The target wiki was misconfigured.

You did not answer correctly.

Use the back button to return the previous page and try again.

To save this page you must answer this question:

Referrers

All Referrers

Tag

Rebuild index for searching

Tag Cloud

Search::FreeText is not available on this system.

Rebuilding index not done.

(Rebuilding the index can only be done once every 12 hours.)

 ... 

Search term missing.

Result pages: 

(%s results)

Tags:

Tags: %s.

No tags

Slideshow:%s

Index of all small pages

Static Copy

Back to %s

Copy to %1 succeeded: %2.

Copy to %1 failed: %2.

Alternatively, use one of the following templates:

Thread: %s

ID parameter is missing.

Thread %s does not exist.

Page %s does not contain a thread.

Add

URL parameter is missing.

Add to %s thread

Below:

URL:

Name:

Too many instances.  Only %s allowed.

Please try again later. Perhaps somebody is running maintenance or doing a long search. Unfortunately the site has limited resources, and so we must ask you for a bit of patience.

Contents

Create a new page for today

This page is a translation of %s. 

The translation is up to date.

The translation is outdated.

The page does not exist.

http://search.barnesandnoble.com/booksearch/isbninquiry.asp?ISBN=%s

http://www.amazon.com/exec/obidos/ISBN=%s

alternate

http://www.pricescan.com/books/BookDetail.asp?isbn=%s

search

Wanted Pages

%s pages

%s, referenced from:

Upload of %s file

Blog

Matching pages:

New

Edit %s.

Title: 

Tags: 

END_OF_TRANSLATION
